#!/bin/ksh

###############################################################
## vabf_hpux_solaris.ksh
###############################################################
## GOP/PFT-DESK/FVA
##-------------------------------------------------------------
## DESCRIPTION :
##. Support a la validation des serveurs sous OS HPUX11.23 et SOLARIS10
##. Usage: vabf_hpux_solaris.ksh
##-------------------------------------------------------------
## VERSIONS    :    @(#) Version 3
##      15/07/2009        creation
##      28/08/2009        modification1:
##                          gestion des mots clef ESPACE et 2POINTS
##                          dans les versions EX:
##                          "RICHPse:3.4-ESPACE-(03-2POINTS-59-ESPACE-PM-ESPACE-01/05/05)"
##                          pour "RICHPse:3.4 (03:59 PM 01/05/05)"
##      28/08/2009        modification2:
##                          gestion des controlles ASSET pour le PACKAGING
##
###############################################################


###############################################################
# Variables                                                   #
###############################################################

######
#PATH#
######
PATH=$PATH:/usr/sbin

#######
#USAGE#
#######
USAGE="Usage: ${0##*/} [ -s STE022008|STE112008 ]"

############
#OS SERVEUR#
############
SRV_OS=`uname -s|sed s/-//`

#############################
#VERSION DE SOCLE DU SERVEUR#
#############################
SRV_FICHIER_STE="/opt/sfrsi/admin/config/socle_version.env"
SRV_STE=`awk -F\= '{print $2}' $SRV_FICHIER_STE 2>/dev/null`

######################
#REFERENCE STE PAR OS#
######################
REF_STE022008_SunOS="STE022008-Packages pour Solaris 10-V1.3.doc"
REF_STE022008_HPUX="STE022008-Packages pour HPUX11iV2-V1.3.doc"
REF_STE112008_SunOS="STE112008 - Solaris 10 U5 x64 - Packages pour Socle Technique de Base - v1.1.pdf"

###################
#REFERENCE STE SRV#
###################
REF_SOCLE=`eval echo \$"REF_${SRV_STE}_${SRV_OS}"`

############################
#REF PKGS SYSTEMES DE BASES#
############################
##STE022008 SunOS
 REF_STE022008_PKGS_SYS_BASES_SunOS="\
RICHPse:3.4-ESPACE-(03-2POINTS-59-ESPACE-PM-ESPACE-01/05/05) \
DTrace:0.99 \
SFWtdmp:3.8.3,REV=2007.04.27.05.33 \
SMCtop:3.6.1 \
SFWvim:6.3,REV=2007.04.27.05.33 \
SMClsof:4.77 \
SFWrsync:2.6.3.1,REV=2007.04.27.05.33 \
SUNWexplo:5.10,REV=2007.09.20.19.12 \
SUNWexplu:5.10,REV=2007.09.20.19.12 \
SFWgcmn:1.0,REV=2007.04.27.05.33 \
SFWncur:5.5,REV=2007.04.27.05.33 \
SFWrline:4.2,REV=2007.04.27.05.33 \
SMClintl:3.4.0 SMCliconv:1.11 \
SMCsudo:1.6.9p13 \
SMClgcc346:3.4.6 \
SMCzlib:1.2.3 \
SMCtcl:8.5.0 \
SMCtk:8.5.0 \
SMCexpect:5.43.0 \
SMCossl:0.9.8f \
SMCosh471:4.7p1 \
WSwebmin:1.400 \
SFRSIadminscripts:1.0.0.4 \
SMClogr:3.7.1"

##STE112008 SunOS
 REF_STE112008_PKGS_SYS_BASES_SunOS="\
DTrace:0.99 \
SFWtdmp:3.8.3,REV=2007.04.26.08.02 \
SMCtop:3.6.1 SMCvim:7.1 SMClsof:4.80 \
SFWrsync:2.6.3.1,REV=2007.04.26.08.02 \
SUNWexplo:5.12,REV=2008.04.23.09.37 \
SUNWexplu:5.12,REV=2008.04.23.09.37 \
SFWgcmn:1.0,REV=2007.04.26.08.02 \
SFWncur:5.5,REV=2007.04.26.08.02 \
SFWrline:4.2,REV=2007.04.26.08.02 \
SMClintl:3.4.0 SMCliconv:1.11 \
SMCsudo:1.6.9p16 \
SMClgcc346:3.4.6 \
SMCzlib:1.2.3 \
SMCrsync:3.0.3 \
SMCtcl:8.5.3 \
SMCtk:8.5.3 \
SMCexpect:5.43.0 \
SMCossl:0.9.8i \
SMCosh511:5.1p1 \
WSwebmin:1.430 \
SFRSIadminscripts:1.0.0.4 \
SMClogr:3.7.6 \
SMCmutt:1.5.18 \
SMClibidn:1.10 \
SMCslang:2.1.4"

##STE022008 SunOS
#OpenSSL:A.00.09.07m.033 \
 REF_STE022008_PKGS_SYS_BASES_HPUX="\
10GigEthr-00:B.11.23.0712.01 \
ATM-00:M.11.23.10 \
B6848BA:1.4.gm.46.13 \
B9073BA:B.11.23.08.03.00.22 \
B9901AA:A.11.23.15.01 \
BUNDLE11i:B.11.23.0409.3 \
Base-VXVM:B.04.10.011 \
CDE-English:B.11.23.0409 \
CDE-French:B.11.23 \
CommonIO:B.11.23.0712 \
DSAUtilities:C.01.00.11 \
DynRootDisk:A.3.0.0.1027 \
EnableVxFS:B.11.23.07 \
FDDI-00:B.11.23.01 \
FEATURE11i:B.11.23.0712.070 \
FIREFOX:2.0.0.4ar.00 \
FibrChanl-00:B.11.23.0712 \
FibrChanl-01:B.11.23.08.02 \
FibrChanl-02:B.11.23.0712 \
FileSysProvider:B.11.23.0706 \
GTK:2.6.8.00.01 \
GigEther-00:B.11.23.0512 \
GigEther-01:B.11.23.0712 \
GuestAVIOStor:B.11.23.0712 \
GuestAvioLan:B.11.23.0712 \
HA_TOOLS:2.11 \
HPUX11i-OE-Ent:B.11.23.0712 \
HPUXBaseAux:B.11.23.0712 \
HPUXBaseOS:B.11.23 \
HPUXBastille:B.3.0.29 \
HPUXMOBILEIP:A.01.01 \
HPUXMOBILEIPV4:B.11.23.0712 \
HostAVIOStor:B.11.23.0712 \
HostAvioLan:B.11.23.0712.01 \
HyprFabrc-00:B.11.23.03.01 \
IEther-00:B.11.23.0712 \
IGNITE:C.7.5.142 \
ISEEPlatform:A.03.95.510.46.03 \
J4269AA:B.04.15.01 \
JAVAOOB:2.04.00 \
Java15JDK:1.5.0.09.00 \
Java15JDKadd:1.5.0.09.00 \
Java15JRE:1.5.0.09.00 \
Java15JREadd:1.5.0.09.00 \
Judy:B.11.23.04.17 \
LVMProvider:R11.23.009 \
MOZILLA:1.7.13.01.00 \
OnlineDiag:B.11.23.12.02 \
ParMgr:B.23.02.01.03 \
ProviderDefault:B.11.23.0712 \
RAID-01:B.11.23.0712 \
Sec00Tools:B.01.04.10 \
SerialSCSI-00:B.11.23.0712 \
SFRSIadminscripts:1.0.0.8 \
SFRSIopensrc:1.0.0.2 \
SwAssistant:C.01.05 \
SysFaultMgmt:B.06.00.04.01 \
SysMgmtWeb:A.2.2.9 \
T1456AA:1.4.2.15.00 \
T1456AAaddon:1.4.2.15.00 \
T1457AA:1.4.2.15.00 \
T1457AAaddon:1.4.2.15.00 \
T1471AA:A.04.50.021 \
T2351AA:B.11.23.08.00.01.01 \
TC-OpenSource:B.11.23.20.12 \
TermIO-00:B.11.23.1.1 \
TokenRing-00:B.11.23.01 \
USB-00:C.01.04.07 \
UtilProvider:A.01.07.16.01 \
WBEMP-LAN-00:B.11.23.0809 \
hpuxwsApache:B.2.0.59.07 \
hpuxwsTomcat:B.5.5.23.02 \
hpuxwsWebmin:A.1.070.10 \
hpuxwsXml:A.2.03 \
iSCSI-00:B.11.23.03c \
nParProvider:B.23.01.07.05 \
perl:D.5.8.8.B \
scsiU320-00:B.11.23.0712"



###############################
#REF PKGS APPLICATIFS DE BASES#
###############################
##STE022008 SunOS
 REF_STE022008_PKGS_APP_BASES_SunOS="\
SFRSIeccmad:6.0.b \
SFRSInetworkerpreinstall:1.0.0.2 \
LGTOclnt:7.3.3.Build.510 \
LGTOman:7.3.3.Build.510 \
SFRSInetworkerscripts:1.0.0.1 \
SFRSIsysload:5.10 \
SFRSIsysloadscripts:1.1 \
SFRSIuama:2.0 \
SFRSIuamascripts:2.0 \
SFRSIctlma:6.2.01.200 \
SFRSIctlmascripts:1.0.0.3 \
SFRSIpatrol:3.7.0.0i"

##STE112008 SunOS
  REF_STE112008_PKGS_APP_BASES_SunOS="\
SFRSInetworkerpreinstall:1.0.0.2 \
LGTOclnt:7.4.2.Build.431 \
LGTOman:7.4.2.Build.431 \
SFRSInetworkerscripts:1.0.0.2 \
SFRSIctlma:6.2.01.200 \
SFRSIctlmascripts:1.0.0.4 \
SFRSIpatrol:3.7.20 \
SFRSIhpecs:1.0.0"

##STE022008 HPUX
 REF_STE022008_PKGS_APP_BASES_HPUX="\
SFRSIpowerpath:5.1.0_b160 \
SFRSIpatrol:3.7.0.0i \
SFRSIctlma:6.2.01.200 \
SFRSIctlmascripts:1.0.0.3 \
SFRSInetwpreinst:1.0.0.2 \
SFRSInetworker:7.3.3 \
SFRSInetwscripts:1.0.0.1 \
SFRSIeccmad:6 \
SFRSIsysload:5.1 \
SFRSIsysloadscripts:1.1 \
SFRSIuama:2.0 \
SFRSIuamascripts:2.0"

#############################
#PKGS APPLICATIFS OPTIONNELS#
#############################
##################
##STE022008 SunOS#
##################
 #BEA.SERVER
  REF_STE022008_PKGS_BEA_SunOS="\
SFRSIbeaaSP4:8.1"

 #FICHIER CFT
  REF_STE022008_PKGS_FICHIER_SunOS="\
SFRSIfichier:1.0"

 #CONNECT DIRECT
 REF_STE022008_PKGS_CONNECT_DIRECT_SunOS="\
SFRSIfichier:3.6.0.0"

 #MQMSRV (serveur)
  REF_STE022008_PKGS_MQMSRV_SunOS="\
SFRSImqmsrvpre:6.0.0 \
gsk7bas:7.0.4.11 \
gsk7bas64:7.0.4.11 \
mqm:6.0.0.0 \
mqm-06-00-02-02: \
SFRSImqmsrvpost:6.0.2.2 \
SFRSImqmscripts:1.0"

 #MQMCLI (Client)
  REF_STE022008_PKGS_MQMCLI_SunOS="\
SFRSImqmclipre:6.0.2.2 \
gsk7bas:7.0.4.11 \
gsk7bas64:7.0.4.11 \
mqm:6.0.2.2 \
SFRSImqmclipost:6.0.2.2"

 #NMO 
  REF_STE022008_PKGS_NMO_SunOS="\
LGTOnmo:4.1,REV=LNMs_2003.Build.48 \
SFRSInmoscripts:1.0.0.1"

 #OR10GEE3X
  REF_STE022008_PKGS_OR10GEE3X_SunOS="\
SFRSIorasetupscripts:1.0.0.10 \
SFRSIor10gee3x:10.2.0.3 \
SFRSIorascripts:1.0.0.6"

 #PATROLKMORA
  REF_STE022008_PKGS_PATROLKMORA_SunOS="\
SFRSIpatrolkmora:8.8.30"

 #WAS61.B
  REF_STE112008_PKGS_WAS61B_SunOS="\
SFRSIwas61b:6.1 jdk1.5:"

 #WAS61.ND
  REF_STE112008_PKGS_WAS61ND_SunOS="\
SFRSIwas61nd:6.1 jdk1.5"

 #WAS61.F
  REF_STE112008_PKGS_WAS61F_SunOS="\
SFRSIwas61f:6.1 jdk1.5"

##################
##STE112008 SunOS#
##################
 #FICHIER
  REF_STE112008_PKGS_FICHIER_SunOS="\
SFRSIsoclefichier:1.1"

 #MQMCLI (client)
  REF_STE112008_PKGS_MQMCLI_SunOS="\
SFRSImqmclipre:6.0.2.2 \
gsk7bas: \
gsk7bas64: \
mqm:"

 #NMO
  REF_STE112008_PKGS_NMO_SunOS="\
LGTOnmo:4.5 \
SFRSInmoscripts:1.0.0.2"

 #OR10GEE3X
  REF_STE112008_PKGS_OR10GEE3X_SunOS="\
SFRSIorasetupscripts:1.0.0.11 \
SFRSIor10gee3x:10.2.0.3 \
SFRSIorascripts:1.0.0.6"

 #PATROLKMORA
  REF_STE112008_PKGS_PATROLKMORA_SunOS="\
SFRSIpatrolkmora:8.900"

 #WAS61.B
  REF_STE112008_PKGS_WAS61B_SunOS="\
SFRSIwas61b:6.1.0.9"

 #WAS61.ND
  REF_STE112008_PKGS_WAS61ND_SunOS="\
SFRSIwas61nd:6.1.0.9"

 #WAS61.F
  REF_STE112008_PKGS_WAS61F_SunOS="\
SFRSIwas61f:6.1.0.9"

 #MySQL
  REF_STE112008_PKGS_MYSQL_SunOS="\
SFRSImysqlmoteur:5.1.29 \
SFRSImysqlscripts:1.0.0.0"

 #JBOSS405
  REF_STE112008_PKGS_JBOSS405_SunOS="\
SFRSIjboss405:4.0.5.GA \
SFRSIjbossjdk:1.5.0_16-b02 \
SFRSIjbossant:1.7.1 \
SFRSIjonagent201:2.0.1.GA \
SFRSIjbossscripts:1.0.0.0 \
SFRSIjbossstart:1.0.0.0"

 #JBOSS420
  REF_STE112008_PKGS_JBOSS420_SunOS="\
SFRSIjboss420:4.2.0.GA \
SFRSIjbossjdk:1.5.0_16-b02 \
SFRSIjbossant:1.7.1 \
SFRSIjonagent201:2.0.1.GA \
SFRSIjbossscripts:1.0.0.0 \
SFRSIjbossstart:1.0.0.0"

 #JBOSS430
  REF_STE112008_PKGS_JBOSS430_SunOS="\
SFRSIjboss430:4.3.0.GA-ESPACE-CP02 \
SFRSIjbossjdk:1.5.0_16-b02 \
SFRSIjbossant:1.7.1 \
SFRSIjonagent201:2.0.1.GA \
SFRSIjbossscripts:1.0.0.0 \
SFRSIjbossstart:1.0.0.0"

 #HPOV agent
  REF_STE112008_PKGS_HPOVagt_SunOS="\
SFRSIhpopenview:8"

#################
##STE022008 HPUX#
#################
 #NMO
 REF_STE112008_PKGS_NMO_HPUX="\
SFRSInmo:4.1.0.0 \
SFRSInmoscripts:1.0.0.0"

 #OR10GEE3X
  REF_STE022008_PKGS_OR10GEE3X_HPUX="\
SFRSIorasetupscripts:1.0.0.10 \
SFRSIor10gee3x:10.2.0.3 \
SFRSIorascripts:1.0.0.5"

 #MQMCLI (client)
  REF_STE022008_PKGS_MQMCLI_HPUX="\
SFRSImqmclipre:6.0.2.2 \
SFRSImqmcli:6.0.2.2 \
SFRSImqmclipost:6.0.2.2"

 #MQMCLI (serveur)
  REF_STE022008_PKGS_MQMSRV_HPUX="\
SFRSImqmsrvpre:6.0.2.2 \
SFRSImqmsrv:6.0 \
SFRSImqmsrvpatch:6.0.2.2 \
SFRSImqmsrvpost:6.0.2.2 \
SFRSImqmscripts:1.0"

 #FICHIER
  REF_STE022008_PKGS_FICHIER_HPUX="\
SFRSIfichier:"

 #PATROLKMORA
  REF_STE022008_PKGS_PATROLKMORA_HPUX="\
SFRSIpatrolkmora:8.8.30"

 #BEA.SERVER
  REF_STE022008_PKGS_BEA_HPUX="\
SFRSIbeaaSP4:8.1"

###############################################################
# Fonctions                                                   #
###############################################################

#############################
#Attente saisie un caractere#
#############################
yesorno() {
 char=""
 stty -echo -icanon min 0 time 0
 while [ "$char" = "" ]
 do
  read char
 done
 stty sane
 printf "$char"
}


###################################################
#Teste la presence des packages,bunble en argument#
###################################################
presencepackage() {
 ###########
 #Arguments#
 ###########
 CTRL_VER="N"
 PKG_UNINST=""
 PKG_VER=""
 SRV_PKG=""
 while getopts vp: opt
 do
  case $opt in
   v) CTRL_VER="O" ;;
   p) PKG_LST=`eval echo $OPTARG`
      if [[ -z $PKG_LST ]]
       then
        printf "\nERREUR: Bundle non defini: $OPTARG\n"
        exit 10
      fi ;;
   *) echo "OPTION non connue dans l appel de la fonction presencepackage"
      exit 1 ;;
  esac
 done

 #############################################
 #Test presence package et version si demande#
 #############################################
 for i in $PKG_LST
 do
  printf "."
  REF_PKG=`echo $i|cut -d\: -f1`
  #REF_VER=`echo $i|cut -d\: -f2`
  #gestion des espace dans les versions
  REF_VER=`echo $i|cut -d\: -f2|sed s/-ESPACE-/" "/g|sed s/-2POINTS-/:/g`
  case $SRV_OS in
   HPUX ) if `swlist -l bundle $REF_PKG >/dev/null 2>&1`
         then                                              #package est present
           SRV_PKG="${SRV_PKG}\tOK: `swlist -l bundle $REF_PKG|grep $REF_PKG`\n"
           if [ "$CTRL_VER" = "O" ]
           then                                            #test version des packages presents
            VER_SRV=`swlist -l bundle $REF_PKG 2>/dev/null|grep ^revision|awk -F\  '{printf $2}' `
            swlist -l bundle ${REF_PKG},r=${REF_VER}>/dev/null 2>&1 || PKG_VER="${PKG_VER}KO: ${REF_PKG}: version attendue-${REF_VER}, version installee-${VER_SRV}\n"
           fi
          else
           PKG_UNINST="${PKG_UNINST}KO: Package ${REF_PKG} non present\n"
         fi ;;
   SunOS ) if `pkginfo -q $REF_PKG`
            then                                           #package est present
             SRV_PKG="${SRV_PKG}\tOK: `pkginfo $REF_PKG`\n"
             if [ "$CTRL_VER" = "O" ]
             then                                          #test version des packages presents
              VER_SRV=`pkginfo -l $REF_PKG|grep VERSION|cut -d\: -f2`
              pkginfo -qv "$REF_VER" $REF_PKG || PKG_VER="${PKG_VER}KO: ${REF_PKG}: version attendue-${REF_VER}, version installee-${VER_SRV}\n"
             fi
            else                                           #package non present
             PKG_UNINST="${PKG_UNINST}KO: Package ${REF_PKG} non present\n"
            fi ;;
  esac
 done


 ############################
 #Affichage resultat du test#
 ############################
 case $CTRL_VER in
  N) if [ "$PKG_UNINST" = "" ]                        #pas de controle version
      then                                            #tous les packages sont presents
       printf "\nTous les packages definis dans \"%s\" sont presents.\n" "$REF_SOCLE"
       printf "$SRV_PKG\n"
      else                                            #manque des packages
       printf "\nDes packages definis dans \"%s\" sont absents:\n" "$REF_SOCLE"
       printf "$SRV_PKG"
       printf "$PKG_UNINST\n"
      fi;;
  O) if [ "$PKG_UNINST" = "" -a "$PKG_VER" = "" ]     #controle version
      then                                            #tous les packages presents et toutes les versions sont OK
       printf "\nTous les packages definis dans \"%s\" sont presents et les versions sont correctes.\n" "$REF_SOCLE"
       printf "$SRV_PKG\n"
      else                                            #manque des packages et ou des versions sont incorrectes
       printf "\nDes packages definis dans \"%s\" sont absents ou ont des versions incorrectes:\n" "$REF_SOCLE"
       printf "$SRV_PKG"
       printf "$PKG_UNINST"
       printf "$PKG_VER\n"
      fi;;
 esac
}



##############################################################
# Traitement                                                 #
##############################################################

#################################################
#Teste et prise en compte des options/parametres#
#################################################
while getopts s: opt
do
 case $opt in
  s) if [[ "$OPTARG" = STE@(02|11)2008 ]]
      then
       if [[ "$SRV_OS" = HPUX && "$OPTARG" = STE112008 ]]
        then
         echo "ERREUR: ${0##*/} : version OS($SRV_OS) et socle demande($OPTARG) incoherents"
         echo $USAGE
         exit 2
        else
         SRV_STE="$OPTARG"
         REF_SOCLE=`eval echo \$"REF_${SRV_STE}_${SRV_OS}"`
       fi
      else
       echo "ERREUR: ${0##*/} : parametre  non gere"
       echo $USAGE
       exit 3
     fi ;;
  *) echo "ERREUR: ${0##*/} : option non geree"
     echo $USAGE
     exit 4;;
 esac
done

if [ -n "$SRV_STE" ]
then

################################
#REFERENTIELS ASSET/EVROULT/UAM#
################################

##########################################################################################################
# Environnement PACKAGING ?
# Recuperation fichier gop_bien.txt, gop_ssa.txt  et gop_liensserveurspack_ssa.txt sur serva1 si packaging
ENVIRONNEMENT=""
echo "\nEnvironnement PACKAGING [y|n]? \c"
yesorno
if [ "$char" = "y" ]
 then
  echo "\nNumero de SSA? \c"
  read SSA
  printf '\n - RECUPERATION DES FICHIERS gop_*.txt DEPUIS SERVA1 SOUS /tmp/:\n'
  ENVIRONNEMENT="PACKAGING"
ftp -nv 10.169.32.82 <<EOF  >/dev/null
user gdonniou Zoe56!
lcd /tmp/
bin
get /tmp/gop_biens.txt
get /tmp/gop_ssa.txt
get /tmp/gop_liensserveurspack_ssa.txt
bye
EOF
fi
##########################################################################################################
clear

   printf '\n###################################################\n'
   printf 'REFERENTIELS ASSET/EVROULT/UAM:\n'
   printf '\n - ASSET:Domaine du serveur dans A7 CENTER GP:\n'
        if [ "$ENVIRONNEMENT" = "PACKAGING" ]
         then
          echo ">grep -i ^`hostname` /tmp/gop_biens.txt|cut -d\| -f4"
          grep -i ^`hostname` /tmp/gop_biens.txt|cut -d\| -f4
         else
          printf 'non gere par ce script pour environnemnt RECETTE et PRODUCTION\n'
        fi
   printf '\n - ASSET:Site geographique declare dans A7 CENTER GP:\n'
        if [ "$ENVIRONNEMENT" = "PACKAGING" ]
         then
          echo ">grep -i ^`hostname` /tmp/gop_biens.txt|cut -d\| -f7"
          grep -i ^`hostname` /tmp/gop_biens.txt|cut -d\| -f7
         else
          printf 'non gere par ce script pour environnemnt RECETTE et PRODUCTION\n'
        fi
   printf '\n - ASSET:Localisation ( Allee et position) declaree dans A7 CENTER GP:\n'
        if [ "$ENVIRONNEMENT" = "PACKAGING" ]
         then
          echo ">grep -i ^`hostname` /tmp/gop_biens.txt|cut -d\| -f7"
          grep -i ^`hostname` /tmp/gop_biens.txt|cut -d\| -f7
         else
          printf 'non gere par ce script pour environnemnt RECETTE et PRODUCTION\n'
        fi
   printf '\n - ASSET:SSA declare dans ASSET CENTER GP:\n'
        if [ "$ENVIRONNEMENT" = "PACKAGING" ]
         then
          echo >grep ^$SSA  /tmp/gop_ssa.txt
          grep ^$SSA /tmp/gop_ssa.txt
         else
          printf 'non gere par ce script pour environnemnt RECETTE et PRODUCTION\n'
        fi
   printf '\n - ASSET:SSA associe au serveur dans ASSET CENTER GP:\n'
        if [ "$ENVIRONNEMENT" = "PACKAGING" ]
         then
          echo ">grep ^$SSA  /tmp/gop_liensserveurspack_ssa.txt|grep -i `hostname`"
          grep ^$SSA /tmp/gop_liensserveurspack_ssa.txt|grep -i `hostname`
         else
          printf 'non gere par ce script pour environnemnt RECETTE et PRODUCTION\n'
        fi
   printf '\n - UAM:Serveurs declares dans UAM:\n'
   printf 'non gere par ce script\n'

rm /tmp/gop_biens.txt 2>/dev/null
rm /tmp/gop_ssa.txt 2>/dev/null
rm /tmp/gop_liensserveurspack_ssa.txt 2>/dev/null


###################
#ACCESSIBILITE/SVG#
###################
   printf '\n###################################################\n'
   printf 'ACCESSIBILITE/SVG:\n'
   printf '\n'
   printf '\n - Connexion reussie avec un cpt nominatif ou usergop:\n'
   printf 'non gere par ce script\n'
   printf '\n - Serveur accessible par la patte svg depuis le srv de sauvegarde:\n'
   printf 'non gere par ce script\n'
   printf '\n - Verification de l ordonnancement de la sauvegarde du serveur:\n'
   printf 'non gere par ce script\n'
   printf '\n - Serveur accessible par le port console administration:\n'
   printf 'non gere par ce script\n'

######
#PAIP#
######
   printf '\n###################################################\n'
   printf 'PAIP:\n'
   printf '\n'

   printf '\n - Nombre @IP declarees:\n'
   echo \>netstat -ni
   netstat -ni

   printf '\n - Serveur dans le reseau demande (coherence VLAN / DMZ / ...) :\n'
   printf 'non gere par ce script\n'

   printf '\n - Routes statiques d apres PAIP :\n'
   echo \>netstat -nrv
   netstat -nrv

   printf '\n - Routes par defaut d apres PAIP :\n'
   echo \>netstat -nrv\|grep default
   netstat -nrv|grep default

   printf '\n - Declaration des interfaces reseau du serveur dans le domaine demande :\n'
   printf 'non gere par ce script\n'

   printf '\n - Utilisation du serveur DNS de l environnement demande :\n'
   echo \>cat /etc/resolv.conf
   cat /etc/resolv.conf

   printf '\n - Alias nom court :\n'
   echo \> nslookup `hostname`
   nslookup `hostname`

   printf '\n - Mecanisme de resolution de nom:file avant DNS :\n'
   echo \>grep ^hosts /etc/nsswitch.conf
   grep ^hosts /etc/nsswitch.conf

########################
#SOCLE TECHNIQUE ETENDU#
########################
   printf '\n###################################################\n'
   printf 'SOCLE TECHNIQUE ETENDU:\n'
   printf '\n'

   printf ' - Fichier local /etc/hosts:\n'
   echo \>grep -v ^# /etc/hosts
   grep -v ^# /etc/hosts

   printf '\n - Packages systemes de bases installes: '
   bundle=\$"REF_${SRV_STE}_PKGS_SYS_BASES_${SRV_OS}"
   presencepackage -p $bundle

   printf '\n - Packages applicatifs de bases installes: '
   bundle=\$"REF_${SRV_STE}_PKGS_APP_BASES_${SRV_OS}"
   presencepackage -p $bundle

   printf '\n - Presence comptes de sauvegarde rman et rootsvg:\n'
   echo \>egrep "^rman|^rootsvg" /etc/passwd
   egrep "^rman|^rootsvg" /etc/passwd

#####
#DDD#
#####
   printf '\n###################################################\n'
   printf 'DDD:\n'

   printf '\n - Hostname:\n'
   echo \> hostname
   hostname

   printf '\n - Nom du Chassis:\n'
   printf 'non gere par ce script\n'

   printf '\n - Marque:\n'
   echo \>uname
   uname

   printf '\n - Modele:\n'
   case $SRV_OS in
    HPUX) echo \>model
           model ;;
    SunOS) echo \>uname -i
             uname -i ;;
    *) echo "OS non gere"
       exit 5 ;;
   esac
   
   printf '\n - Nombre de CPU:\n'
   case $SRV_OS in
    HPUX) echo \>machinfo\|grep \'Number of CPUs\'
           machinfo|grep 'Number of CPUs' ;;
    SunOS) echo \>psrinfo -p
           psrinfo -p ;;
    *) echo "OS non gere"
       exit 6 ;;
   esac

   printf '\n - Cadence CPU:\n'
   case $SRV_OS in
    HPUX) echo \>machinfo\|grep \'Clock speed\'
           machinfo|grep 'Clock speed' ;;
    SunOS) echo \>psrinfo -pv
             psrinfo -pv ;;
    *) echo "OS non gere"
       exit 7 ;;
   esac
   
   printf '\n - Taille de la RAM:\n'
   case $SRV_OS in
    HPUX) echo \>machinfo\|grep \'Memory\'
           machinfo|grep 'Memory' ;;
    SunOS) echo \>prtconf\|grep \'Memory size\'
             prtconf|grep 'Memory size' ;;
    *) echo "OS non gere"
       exit 8 ;;
   esac

   echo "\n - Applicatifs optionnels demandes[y|n]? \c"
   yesorno
   if [ "$char" = "y" ]
   then
    #ORACLE 10.2 moteur
     echo "\nORACLE 10G moteur [y|n]? \c"
     yesorno
     if [ "$char" = "y" ]
     then
      bundle=\$"REF_${SRV_STE}_PKGS_OR10GEE3X_${SRV_OS}"
      presencepackage -p $bundle
      bundle=\$"REF_${SRV_STE}_PKGS_NMO_${SRV_OS}"         #Sauvegarde oracle
      presencepackage -p $bundle                
      bundle=\$"REF_${SRV_STE}_PKGS_PATROLKMORA_${SRV_OS}" #Monitoring oracle
      presencepackage -p $bundle                
      echo \> grep ^oracle\: /etc/passwd
      grep ^oracle\: /etc/passwd
     fi
     
    #ORACLE 10.2 client
     echo "\nORACLE 10G client [y|n]? \c"
     yesorno
     if [ "$char" = "y" ]
     then
      bundle=\$"REF_${SRV_STE}_PKGS_OR10GEE3X_${SRV_OS}"
      presencepackage -p $bundle
      echo \> grep ^oracle\: /etc/passwd
      grep ^oracle\: /etc/passwd
     fi

    #MQ SERIE CLIENT
     echo "\nMQ SERIES client [y|n]? \c"
     yesorno
     if [ "$char" = "y" ]
     then
      bundle=\$"REF_${SRV_STE}_PKGS_MQMCLI_${SRV_OS}"
      presencepackage -p $bundle
      echo \> grep ^mqm\: /etc/passwd
      grep ^mqm\: /etc/passwd
     fi

    #MQ SERIE SERVEUR
     echo "\nMQ SERIES serveur (seulement en STE022008)[y|n]? \c"
     yesorno
     if [ "$char" = "y" ]
     then
      bundle=\$"REF_${SRV_STE}_PKGS_MQMSRV_${SRV_OS}"
      presencepackage -p $bundle
      echo \> grep ^mqm\: /etc/passwd
      grep ^mqm\: /etc/passwd
     fi

    #CFT
     echo "\nCFT [y|n]? \c"
     yesorno
     if [ "$char" = "y" ]
     then
      bundle=\$"REF_${SRV_STE}_PKGS_FICHIER_${SRV_OS}"
      presencepackage -p $bundle
      echo \> grep ^syscft\: /etc/passwd
      grep ^syscft\: /etc/passwd
     fi

    #CONNECT DIRECT
     echo "\nCONNECT DIRECT [y|n]? \c"
     yesorno
     if [ "$char" = "y" ]
     then
      bundle=\$"REF_${SRV_STE}_PKGS_CONNECT_DIRECT_${SRV_OS}"
      presencepackage -p $bundle
      echo \> grep ^syscft\: /etc/passwd
      grep ^syscft\: /etc/passwd
     fi

    #WEBSPHERE
     ##WAS61.B
      echo "\nWAS61.B [y|n]? \c"
      yesorno
      if [ "$char" = "y" ]
      then
       bundle=\$"REF_${SRV_STE}_PKGS_WAS61B_${SRV_OS}"
       presencepackage -p $bundle
       echo \> grep ^was\: /etc/passwd
       grep ^was\: /etc/passwd
      fi
     ##WAS61.ND
      echo "\nWAS61.ND [y|n]? \c"
      yesorno
      if [ "$char" = "y" ]
      then
       bundle=\$"REF_${SRV_STE}_PKGS_WAS61ND_${SRV_OS}"
       presencepackage -p $bundle
       echo \> grep ^was\: /etc/passwd
       grep ^was\: /etc/passwd
      fi
     ##WAS61.F
      echo "\nWAS61.F [y|n]? \c"
      yesorno
      if [ "$char" = "y" ]
      then
       bundle=\$"REF_${SRV_STE}_PKGS_WAS61F_${SRV_OS}"
       presencepackage -p $bundle
       echo \> grep ^was\: /etc/passwd
       grep ^was\: /etc/passwd
      fi

    #JBOSS
     ##JBOSS 4.0.5
      echo "\nJBOSS 4.0.5 [y|n]? \c"
      yesorno
      if [ "$char" = "y" ]
      then
       bundle=\$"REF_${SRV_STE}_PKGS_JBOSS405_${SRV_OS}"
       presencepackage -p $bundle
      fi
     ##JBOSS 4.2.0
      echo "\nJBOSS 4.2.0 [y|n]? \c"
      yesorno
      if [ "$char" = "y" ]
      then
       bundle=\$"REF_${SRV_STE}_PKGS_JBOSS420_${SRV_OS}"
       presencepackage -p $bundle
      fi
     ##JBOSS 4.3.0
      echo "\nJBOSS 4.3.0 [y|n]? \c"
      yesorno
      if [ "$char" = "y" ]
      then
       bundle=\$"REF_${SRV_STE}_PKGS_JBOSS430_${SRV_OS}"
       presencepackage -p $bundle
      fi
     fi
else
 printf "ERREUR: Socle non defini:\n"
 printf "\t $SRV_FICHIER_STE inexistant, pour forcer une version de socle utilisez l'option -s.\n"
 echo $USAGE
 exit 9
fi
